# History

## 0.0.1 (2021-09-27)

* Implement basic `minos microservice new` and `minos microservice init` commands.
* First version on pypi.


## 0.1.0 (2022-02-03)

* Add `minos set broker` command.
* Add `minos set database` command.
* Add `minos set discovery` command.
* Add `minos set api-gateway` command.
* Add `minos deploy project` command.
* Add `minos deploy microservice` command.
* Refactor `minos project new` command as `minos new project`.
* Refactor `minos project init` command as `minos init project`.
* Refactor `minos microservice new` command as `minos new microservice`.
* Refactor `minos microservice init` command as `minos init microservice`.

## 0.1.1 (2022-02-03)

* Update links to the repository and website.

## 0.1.2 (2022-02-10)

* Docker as default deployer.
* Fixed bugs.

## 0.1.3 (2022-02-11)

* Deploy command is no longer supported.
* Quickstart updated for better user experience.

## 0.2.0 (2022-02-16)

* Microservices are now created within `microservices` directory.
* `version` commands added.
* Minos CLI no longer generates `__pycache__` archives.
* `init` command is no longer supported.
